searchData={"content_type":"text/markdown","items":[{"doc":"Cachetastic main module for interacting with the cache.\n\nThis module provides a unified interface for various caching mechanisms\nsuch as ETS and Redis, with built-in fault tolerance. It allows you to\nperform basic caching operations like put, get, delete, and clear.","ref":"Cachetastic.html","title":"Cachetastic","type":"module"},{"doc":"You can configure the backends and fault tolerance settings in your `config/config.exs`:\n\n    use Mix.Config\n\n    config :cachetastic,\n      backends: [\n        ets: [ttl: 600],\n        redis: [host: \"localhost\", port: 6379, ttl: 3600]\n      ],\n      fault_tolerance: [primary: :redis, backup: :ets]","ref":"Cachetastic.html#module-configuration","title":"Configuration - Cachetastic","type":"module"},{"doc":"# Start the cache\n    {:ok, _pid} = Cachetastic.start_link()\n\n    # Perform cache operations\n    Cachetastic.put(\"key\", \"value\")\n    {:ok, value} = Cachetastic.get(\"key\")\n    Cachetastic.delete(\"key\")\n    Cachetastic.clear()","ref":"Cachetastic.html#module-examples","title":"Examples - Cachetastic","type":"module"},{"doc":"Clears all values from the cache.","ref":"Cachetastic.html#clear/0","title":"Cachetastic.clear/0","type":"function"},{"doc":"Deletes a value from the cache by key.","ref":"Cachetastic.html#delete/1","title":"Cachetastic.delete/1","type":"function"},{"doc":"Gets a value from the cache by key.","ref":"Cachetastic.html#get/1","title":"Cachetastic.get/1","type":"function"},{"doc":"Puts a value in the cache with the specified key and optional TTL.","ref":"Cachetastic.html#put/3","title":"Cachetastic.put/3","type":"function"},{"doc":"Starts the cache with the primary backend.","ref":"Cachetastic.html#start_link/0","title":"Cachetastic.start_link/0","type":"function"},{"doc":"ETS backend for Cachetastic.\n\nThis module implements the Cachetastic.Behaviour using ETS as the storage mechanism.","ref":"Cachetastic.Backend.ETS.html","title":"Cachetastic.Backend.ETS","type":"module"},{"doc":"* `:table_name` - The name of the ETS table (default: :cachetastic)\n  * `:ttl` - The time-to-live for cache entries in seconds (default: 600)","ref":"Cachetastic.Backend.ETS.html#module-options","title":"Options - Cachetastic.Backend.ETS","type":"module"},{"doc":"# Start the ETS backend\n    {:ok, state} = Cachetastic.Backend.ETS.start_link(table_name: :my_cache, ttl: 3600)\n\n    # Put a value in the cache\n    Cachetastic.Backend.ETS.put(state, \"key\", \"value\")\n\n    # Get a value from the cache\n    {:ok, value} = Cachetastic.Backend.ETS.get(state, \"key\")\n\n    # Delete a value from the cache\n    :ok = Cachetastic.Backend.ETS.delete(state, \"key\")\n\n    # Clear all values from the cache\n    :ok = Cachetastic.Backend.ETS.clear(state)","ref":"Cachetastic.Backend.ETS.html#module-examples","title":"Examples - Cachetastic.Backend.ETS","type":"module"},{"doc":"Clears all values from the ETS cache.","ref":"Cachetastic.Backend.ETS.html#clear/1","title":"Cachetastic.Backend.ETS.clear/1","type":"function"},{"doc":"Deletes a value from the ETS cache by key.","ref":"Cachetastic.Backend.ETS.html#delete/2","title":"Cachetastic.Backend.ETS.delete/2","type":"function"},{"doc":"Gets a value from the ETS cache by key.","ref":"Cachetastic.Backend.ETS.html#get/2","title":"Cachetastic.Backend.ETS.get/2","type":"function"},{"doc":"Puts a value in the ETS cache.","ref":"Cachetastic.Backend.ETS.html#put/4","title":"Cachetastic.Backend.ETS.put/4","type":"function"},{"doc":"Starts the ETS backend with the given options.","ref":"Cachetastic.Backend.ETS.html#start_link/1","title":"Cachetastic.Backend.ETS.start_link/1","type":"function"},{"doc":"Redis backend for Cachetastic.\n\nThis module implements the Cachetastic.Behaviour using Redis as the storage mechanism.","ref":"Cachetastic.Backend.Redis.html","title":"Cachetastic.Backend.Redis","type":"module"},{"doc":"* `:host` - The Redis host (default: \"localhost\")\n  * `:port` - The Redis port (default: 6379)\n  * `:ttl` - The time-to-live for cache entries in seconds (default: 3600)","ref":"Cachetastic.Backend.Redis.html#module-options","title":"Options - Cachetastic.Backend.Redis","type":"module"},{"doc":"# Start the Redis backend\n    {:ok, state} = Cachetastic.Backend.Redis.start_link(host: \"localhost\", port: 6379, ttl: 3600)\n\n    # Put a value in the cache\n    Cachetastic.Backend.Redis.put(state, \"key\", \"value\")\n\n    # Get a value from the cache\n    {:ok, value} = Cachetastic.Backend.Redis.get(state, \"key\")\n\n    # Delete a value from the cache\n    :ok = Cachetastic.Backend.Redis.delete(state, \"key\")\n\n    # Clear all values from the cache\n    :ok = Cachetastic.Backend.Redis.clear(state)","ref":"Cachetastic.Backend.Redis.html#module-examples","title":"Examples - Cachetastic.Backend.Redis","type":"module"},{"doc":"Clears all values from the Redis cache.","ref":"Cachetastic.Backend.Redis.html#clear/1","title":"Cachetastic.Backend.Redis.clear/1","type":"function"},{"doc":"Deletes a value from the Redis cache by key.","ref":"Cachetastic.Backend.Redis.html#delete/2","title":"Cachetastic.Backend.Redis.delete/2","type":"function"},{"doc":"Gets a value from the Redis cache by key.","ref":"Cachetastic.Backend.Redis.html#get/2","title":"Cachetastic.Backend.Redis.get/2","type":"function"},{"doc":"Puts a value in the Redis cache.","ref":"Cachetastic.Backend.Redis.html#put/4","title":"Cachetastic.Backend.Redis.put/4","type":"function"},{"doc":"Starts the Redis backend with the given options.","ref":"Cachetastic.Backend.Redis.html#start_link/1","title":"Cachetastic.Backend.Redis.start_link/1","type":"function"},{"doc":"","ref":"Cachetastic.Behaviour.html","title":"Cachetastic.Behaviour","type":"behaviour"},{"doc":"","ref":"Cachetastic.Behaviour.html#c:clear/1","title":"Cachetastic.Behaviour.clear/1","type":"callback"},{"doc":"","ref":"Cachetastic.Behaviour.html#c:delete/2","title":"Cachetastic.Behaviour.delete/2","type":"callback"},{"doc":"","ref":"Cachetastic.Behaviour.html#c:get/2","title":"Cachetastic.Behaviour.get/2","type":"callback"},{"doc":"","ref":"Cachetastic.Behaviour.html#c:put/4","title":"Cachetastic.Behaviour.put/4","type":"callback"},{"doc":"","ref":"Cachetastic.Behaviour.html#c:start_link/1","title":"Cachetastic.Behaviour.start_link/1","type":"callback"},{"doc":"Handles configuration and backend initialization for Cachetastic.\n\nThis module provides functions to start the backends and retrieve the primary\nand backup backend configurations from the application environment.","ref":"Cachetastic.Config.html","title":"Cachetastic.Config","type":"module"},{"doc":"# Start the primary backend\n    {:ok, pid} = Cachetastic.Config.start_backend(:redis)\n\n    # Get the primary backend\n    primary_backend = Cachetastic.Config.primary_backend()\n\n    # Get the backup backend\n    backup_backend = Cachetastic.Config.backup_backend()","ref":"Cachetastic.Config.html#module-examples","title":"Examples - Cachetastic.Config","type":"module"},{"doc":"Returns the backup backend configuration.","ref":"Cachetastic.Config.html#backup_backend/0","title":"Cachetastic.Config.backup_backend/0","type":"function"},{"doc":"Returns the primary backend configuration.","ref":"Cachetastic.Config.html#primary_backend/0","title":"Cachetastic.Config.primary_backend/0","type":"function"},{"doc":"Starts the specified backend and returns its state.","ref":"Cachetastic.Config.html#start_backend/1","title":"Cachetastic.Config.start_backend/1","type":"function"},{"doc":"","ref":"Cachetastic.FaultTolerance.html","title":"Cachetastic.FaultTolerance","type":"module"},{"doc":"","ref":"Cachetastic.FaultTolerance.html#with_fallback/2","title":"Cachetastic.FaultTolerance.with_fallback/2","type":"function"},{"doc":"# Cachetastic","ref":"readme.html","title":"Cachetastic","type":"extras"},{"doc":"**Cachetastic** is a powerful and user-friendly caching library for Elixir. The goal is to provide a unified interface for various caching mechanisms like ETS and Redis, with built-in fault tolerance.","ref":"readme.html#overview","title":"Overview - Cachetastic","type":"extras"},{"doc":"- **Unified Interface**: Interact with different caching backends through a consistent API.\n- **Hybrid Caching**: Combine in-memory caching with persistent storage.\n- **Fault Tolerance**: Automatically handle failures in the primary backend.","ref":"readme.html#features","title":"Features - Cachetastic","type":"extras"},{"doc":"Add `cachetastic` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:cachetastic, \"~> 0.1.0\"},\n    {:redix, \"~> 1.0\"},\n  ]\nend\n```\n\nRun `mix deps.get` to fetch the dependencies.","ref":"readme.html#installation","title":"Installation - Cachetastic","type":"extras"},{"doc":"","ref":"readme.html#usage","title":"Usage - Cachetastic","type":"extras"},{"doc":"Define the backends and fault tolerance configuration in `config/config.exs`:\n\n```elixir\nuse Mix.Config\n\nconfig :cachetastic,\n  backends: [\n    ets: [ttl: 600],\n    redis: [host: \"localhost\", port: 6379, ttl: 3600]\n  ],\n  fault_tolerance: [primary: :redis, backup: :ets]\n```","ref":"readme.html#configuration","title":"Configuration - Cachetastic","type":"extras"},{"doc":"Initialize the cache and perform basic operations:\n\n```elixir\n# Start the cache\n{:ok, _pid} = Cachetastic.start_link()\n\n# Cache operations\nCachetastic.put(\"key\", \"value\")\n{:ok, value} = Cachetastic.get(\"key\")\nCachetastic.delete(\"key\")\nCachetastic.clear()\n```","ref":"readme.html#basic-operations","title":"Basic Operations - Cachetastic","type":"extras"},{"doc":"Here's an example of how you can integrate Cachetastic into your own Elixir application:\n\n#### Step 1: Add Cachetastic to Your Dependencies\n\nUpdate your `mix.exs` file to include Cachetastic as a dependency:\n\n```elixir\ndefp deps do\n  [\n    {:cachetastic, \"~> 0.1.0\"}\n  ]\nend\n```\n\nRun `mix deps.get` to fetch the dependencies.\n\n#### Step 2: Configure Cachetastic\n\nAdd the configuration for Cachetastic in your `config/config.exs` file:\n\n```elixir\nuse Mix.Config\n\nconfig :cachetastic,\n  backends: [\n    ets: [ttl: 600],\n    redis: [host: \"localhost\", port: 6379, ttl: 3600]\n  ],\n  fault_tolerance: [primary: :redis, backup: :ets]\n```\n\n#### Step 3: Use Cachetastic in Your Application\n\nIn your application module, start Cachetastic and use it to perform caching operations:\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      # Start the Cachetastic cache\n      {Cachetastic, []}\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\nNow you can use Cachetastic to perform caching operations anywhere in your application:\n\n```elixir\ndefmodule MyApp.SomeModule do\n  def some_function do\n    # Put a value in the cache\n    Cachetastic.put(\"my_key\", \"my_value\")\n\n    # Get a value from the cache\n    case Cachetastic.get(\"my_key\") do\n      {:ok, value} -> IO.puts(\"Got value: #{value}\")\n      :error -> IO.puts(\"Key not found\")\n    end\n\n    # Delete a value from the cache\n    Cachetastic.delete(\"my_key\")\n\n    # Clear the entire cache\n    Cachetastic.clear()\n  end\nend\n```","ref":"readme.html#example-implementation","title":"Example Implementation - Cachetastic","type":"extras"},{"doc":"Feel free to open issues and pull requests. We appreciate your contributions!","ref":"readme.html#contribution","title":"Contribution - Cachetastic","type":"extras"},{"doc":"This project is licensed under the MIT License.","ref":"readme.html#license","title":"License - Cachetastic","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}